@@ -1,4 +1,4 @@
-/* $Revision: 1.2 $ */
+/* $Revision: 1.3 $ */
 /*
  * "gpgp" Gnome/GTK Front for PGP
  * Copyright (C) 1998  Max Valianskiy
@@ -25,12 +25,29 @@
 
 #include <gnome.h>
 
+#define GPGP_OFFICIAL_NAME      "Gnome PGP"
+#define GPGP_ABBREVIATED_NAME   "gpgp"
+#define GPGP_AUTHOR_0           "Max Valianskiy"
+#define GPGP_COPYRIGHT_NOTICE   "(C) 1998-99 Max Valianskiy and others"
+#define GPGP_WEBSITE            "http://www.geocities.com/SiliconValley/Chip/3708"
+
 #define GPGP_OPTIONS_FILE       "/gpgp/Options/"
 #define ENV_GNUPGHOME           "GNUPGHOME"
+#define ENV_PGPPASS             "PGPPASS"
 #define DIR_GNUPGHOME           ".gnupg"
 
 #define DEF_PUBRING_FILE        "pubring.gpg"
 #define DEF_SECRING_FILE        "secring.gpg"
+#define GPGP_USES_DEFAULT_KEYRING       1
+
+
+/*
+ * Configuration sections
+ */
+#define GPGP_CONFIG_APPLICATION "gpgp-app"
+#define GPGP_CONFIG_RINGS       GPGP_CONFIG_APPLICATION "/rings"
+#define GPGP_CONFIG_PUBRING     GPGP_CONFIG_RINGS "/0"
+#define GPGP_CONFIG_SECRING     GPGP_CONFIG_RINGS "/1"
 
 #ifdef __cplusplus
 extern "C" {
@@ -84,6 +101,9 @@ void update_gpgp_options();
 */
 
 void gpgp_init(GnomeApp* app, int use_status);
+void gpgp_MessageBox(const gchar *type, const gchar *text);
+void gpgp_MessageInsufficientMemory(const char *module, int size);
+void LogTextMessage(const char *msg);
 
 /*******************************************************************/
 /*    GnomePgpKeyring                                               */
@@ -241,7 +261,7 @@ struct _GnomePgpUnSign
   char* obuf;
   int obufsize;
 
-  char* filename; /* filename read from packet */
+  char *filename; /* filename read from packet */
 
   const char* error_info;
 };
@@ -257,7 +277,7 @@ struct _GnomePgpUnSignClass
 guint          gnome_pgp_unsign_get_type  (void);
 
 
-GtkWidget*     gnome_pgp_unsign_new       (char* buf, int bufsize);
+GtkWidget *gnome_pgp_unsign_new(char *buf, int bufsize, const char *filename);
 
 /* this function just starts process (it can terminate before end of
    decryption/cheching */
