@@ -1,4 +1,4 @@
-/* $Revision: 1.2 $ */
+/* $Revision: 1.3 $ */
 /*
  *  gpgp: Gnome/GTK Front for PGP
  *  Copyright (C) 1998  Max Valianskiy
@@ -21,6 +21,7 @@
 #include "../config.h"
 #include "../version.h"
 
+#include <assert.h>
 #include <gnome.h>
 
 #include "gpgp.h"
@@ -152,44 +153,79 @@ static void gnome_pgp_sign_init (GnomePgpSign *page)
     gtk_widget_show(box3);
 
     page->sign = GTK_CHECK_BUTTON(gtk_check_button_new_with_label(_("Sign")));
-    gtk_box_pack_start(GTK_BOX(box3), GTK_WIDGET(page->sign), TRUE, TRUE, GNOME_PAD_SMALL);
-    gtk_signal_connect (GTK_OBJECT (page->sign), "toggled",
-                        GTK_SIGNAL_FUNC (toggle_sign_cb),
-                        page);
+    gtk_box_pack_start(
+        GTK_BOX(box3),
+        GTK_WIDGET(page->sign),
+        TRUE,
+        TRUE,
+        GNOME_PAD_SMALL);
+    gtk_signal_connect(
+        GTK_OBJECT (page->sign),
+        "toggled",
+        GTK_SIGNAL_FUNC (toggle_sign_cb),
+        page);
     gtk_widget_show(GTK_WIDGET(page->sign)); 
 
     page->sec = GNOME_ENTRY(gnome_entry_new("seckey"));
-    gtk_box_pack_start(GTK_BOX(box3), GTK_WIDGET(page->sec), TRUE, TRUE, GNOME_PAD_SMALL);
-    gtk_entry_set_text(GTK_ENTRY(gnome_entry_gtk_entry(page->sec)), gpgp_options.defkey);
+    gtk_box_pack_start(
+        GTK_BOX(box3),
+        GTK_WIDGET(page->sec),
+        TRUE,
+        TRUE,
+        GNOME_PAD_SMALL);
+    gtk_entry_set_text(
+        GTK_ENTRY(gnome_entry_gtk_entry(page->sec)),
+        gpgp_options.defkey);
     gtk_widget_show(GTK_WIDGET(page->sec));
 
     page->bsign=GTK_BUTTON(gtk_button_new_with_label(_("Choose key")));
-    gtk_box_pack_start(GTK_BOX(box3),GTK_WIDGET(page->bsign), FALSE, FALSE, GNOME_PAD_SMALL);
-    gtk_signal_connect (GTK_OBJECT (GTK_WIDGET(page->bsign)), "clicked",
-                        GTK_SIGNAL_FUNC (sign_cb),
-                        page);
+    gtk_box_pack_start(
+        GTK_BOX(box3),
+        GTK_WIDGET(page->bsign),
+        FALSE,
+        FALSE,
+        GNOME_PAD_SMALL);
+    gtk_signal_connect(
+        GTK_OBJECT(GTK_WIDGET(page->bsign)),
+        "clicked",
+        GTK_SIGNAL_FUNC(sign_cb),
+        page);
     gtk_widget_show(GTK_WIDGET(page->bsign)); 
  
     /* password box */
     box1 = gtk_hbox_new(FALSE,0);
-    gtk_box_pack_start(GTK_BOX(box2), box1, FALSE, FALSE, GNOME_PAD_SMALL);
+    gtk_box_pack_start(
+        GTK_BOX(box2),
+        box1,
+        FALSE,
+        FALSE,
+        GNOME_PAD_SMALL);
     gtk_widget_show(box1);
  
-    page->enable = GTK_CHECK_BUTTON(gtk_check_button_new_with_label(_("Use PGPPASS")));
-    gtk_box_pack_start(GTK_BOX(box1), GTK_WIDGET(page->enable), TRUE, TRUE, GNOME_PAD_SMALL);
-    gtk_signal_connect (GTK_OBJECT (page->enable), "toggled",
-                        GTK_SIGNAL_FUNC (toggle_pgppass_cb),
-                        page);
-    /*
-     * PGPPASS check box may be disabled if it doesn't work,
-     * so we check the state here and enable/disable it as needed.
-     */
-    gtk_widget_set_sensitive(GTK_WIDGET(page->enable), !pgppass_ignore);
+    page->enable = GTK_CHECK_BUTTON(
+        gtk_check_button_new_with_label(_("Use PGPPASS")));
+    gtk_box_pack_start(
+        GTK_BOX(box1),
+        GTK_WIDGET(page->enable),
+        TRUE,
+        TRUE,
+        GNOME_PAD_SMALL);
+    gtk_signal_connect(
+        GTK_OBJECT (page->enable),
+        "toggled",
+        GTK_SIGNAL_FUNC(toggle_pgppass_cb),
+        page);
+    gtk_widget_set_sensitive(GTK_WIDGET(page->enable), FALSE);
     gtk_widget_show(GTK_WIDGET(page->enable)); 
   
     page->pass = GTK_ENTRY(gtk_entry_new());
     gtk_entry_set_visibility(page->pass, FALSE);
-    gtk_box_pack_start(GTK_BOX(box1), GTK_WIDGET(page->pass), TRUE, TRUE, GNOME_PAD_SMALL);
+    gtk_box_pack_start(
+        GTK_BOX(box1),
+        GTK_WIDGET(page->pass),
+        TRUE,
+        TRUE,
+        GNOME_PAD_SMALL);
     gtk_widget_show(GTK_WIDGET(page->pass));
 
     /* Encrypt */
@@ -202,14 +238,26 @@ static void gnome_pgp_sign_init (GnomePgpSign *page)
     gtk_widget_show(box4);
 
     page->enc = GTK_CHECK_BUTTON(gtk_check_button_new_with_label(_("Encrypt")));
-    gtk_box_pack_start(GTK_BOX(box4), GTK_WIDGET(page->enc), TRUE, TRUE, GNOME_PAD_SMALL);
-    gtk_signal_connect (GTK_OBJECT (page->enc), "toggled",
-                        GTK_SIGNAL_FUNC (toggle_enc_cb),
-                        page);
+    gtk_box_pack_start(
+        GTK_BOX(box4),
+        GTK_WIDGET(page->enc),
+        TRUE,
+        TRUE,
+        GNOME_PAD_SMALL);
+    gtk_signal_connect(
+        GTK_OBJECT (page->enc),
+        "toggled",
+        GTK_SIGNAL_FUNC (toggle_enc_cb),
+        page);
     gtk_widget_show(GTK_WIDGET(page->enc)); 
   
     page->pub = GNOME_ENTRY(gnome_entry_new("pubkey"));
-    gtk_box_pack_start(GTK_BOX(box4), GTK_WIDGET(page->pub), TRUE, TRUE, GNOME_PAD_SMALL);
+    gtk_box_pack_start(
+        GTK_BOX(box4),
+        GTK_WIDGET(page->pub),
+        TRUE,
+        TRUE,
+        GNOME_PAD_SMALL);
     gtk_widget_show(GTK_WIDGET(page->pub));
 
     page->benc=GTK_BUTTON(gtk_button_new_with_label(_("Choose key")));
@@ -228,18 +276,28 @@ static void gnome_pgp_sign_init (GnomePgpSign *page)
     gtk_container_add(GTK_CONTAINER(frame3),box5);
     gtk_widget_show(box5);
 
-    page->textmode = GTK_CHECK_BUTTON(gtk_check_button_new_with_label(_("Text mode")));
-    gtk_box_pack_start(GTK_BOX(box5), GTK_WIDGET(page->textmode), TRUE, TRUE, GNOME_PAD_SMALL);
+    page->textmode = GTK_CHECK_BUTTON(
+        gtk_check_button_new_with_label(_("Text mode")));
+    gtk_box_pack_start(
+        GTK_BOX(box5),
+        GTK_WIDGET(page->textmode),
+        TRUE, TRUE, GNOME_PAD_SMALL);
     gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(page->textmode),1);
     gtk_widget_show(GTK_WIDGET(page->textmode)); 
  
-    page->armor = GTK_CHECK_BUTTON(gtk_check_button_new_with_label(_("Ascii Armor")));
-    gtk_box_pack_start(GTK_BOX(box5), GTK_WIDGET(page->armor), TRUE, TRUE, GNOME_PAD_SMALL);
+    page->armor = GTK_CHECK_BUTTON(
+        gtk_check_button_new_with_label(_("Ascii Armor")));
+    gtk_box_pack_start(
+        GTK_BOX(box5), GTK_WIDGET(page->armor),
+        TRUE, TRUE, GNOME_PAD_SMALL);
     gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(page->armor),1);
     gtk_widget_show( GTK_WIDGET(page->armor)); 
  
-    page->clearsig = GTK_CHECK_BUTTON(gtk_check_button_new_with_label(_("Clear Signature")));
-    gtk_box_pack_start(GTK_BOX(box5), GTK_WIDGET(page->clearsig), TRUE, TRUE, GNOME_PAD_SMALL);
+    page->clearsig = GTK_CHECK_BUTTON(
+        gtk_check_button_new_with_label(_("Clear Signature")));
+    gtk_box_pack_start(
+        GTK_BOX(box5), GTK_WIDGET(page->clearsig),
+        TRUE, TRUE, GNOME_PAD_SMALL);
     gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(page->clearsig),0);
     gtk_signal_connect (GTK_OBJECT (page->clearsig), "toggled",
                         GTK_SIGNAL_FUNC (toggle_clr_cb),
@@ -248,19 +306,22 @@ static void gnome_pgp_sign_init (GnomePgpSign *page)
   
     /* buttonbox2 */
     buttonbox2 = gtk_hbox_new(FALSE,0);
-    gtk_box_pack_start(GTK_BOX(box), buttonbox2, FALSE, FALSE, GNOME_PAD_SMALL);
+    gtk_box_pack_start(
+        GTK_BOX(box), buttonbox2, FALSE, FALSE, GNOME_PAD_SMALL);
     gtk_widget_show(buttonbox2);
  
     /* buttons */
     bok=gnome_stock_button(GNOME_STOCK_BUTTON_OK);
-    gtk_box_pack_start(GTK_BOX(buttonbox2),bok, FALSE, FALSE, GNOME_PAD_SMALL);
+    gtk_box_pack_start(
+        GTK_BOX(buttonbox2),bok, FALSE, FALSE, GNOME_PAD_SMALL);
     gtk_signal_connect (GTK_OBJECT (bok), "clicked",
                         GTK_SIGNAL_FUNC (go_cb),
                         page);
     gtk_widget_show(bok); 
 
     bcancel=gnome_stock_button(GNOME_STOCK_BUTTON_CANCEL);
-    gtk_box_pack_start(GTK_BOX(buttonbox2),bcancel, FALSE, FALSE, GNOME_PAD_SMALL);
+    gtk_box_pack_start(
+        GTK_BOX(buttonbox2),bcancel, FALSE, FALSE, GNOME_PAD_SMALL);
     gtk_signal_connect (GTK_OBJECT (bcancel), "clicked",
                         GTK_SIGNAL_FUNC (cancel_cb),
                         page);
@@ -270,18 +331,31 @@ static void gnome_pgp_sign_init (GnomePgpSign *page)
     toggle_enc_cb(GTK_WIDGET(page->sign), page);
 }
 
+/*
+ * gnome_pgp_sign_new()
+ *
+ * Procedure initiates signing/encryption action.
+ *
+ * Parameters:
+ * buf          - data buffer to sign/encrypt
+ * bufsize      - size of that data buffer
+ * filename     - file name where the data comes from
+ *
+ * History:
+ * 19-May-99 tftp       Added several assert() macros.
+ */
 GtkWidget *gnome_pgp_sign_new(char* buf, int bufsize, char* filename)
 {
     GnomePgpSign* page;
 
+    assert(buf != NULL);
+    assert(bufsize >= 0);
+
     page = gtk_type_new (gnome_pgp_sign_get_type ());
  
     page->buf = buf;
     page->bufsize = bufsize;
     page->filename = filename;
-    if (!page->filename)
-        page->filename = "noname";
- 
     return GTK_WIDGET (page);
 }
 
@@ -336,56 +410,15 @@ static void sign_cb(GtkWidget *widget, GnomePgpSign *data)
 
 static void cancel_cb (GtkWidget *widget, gpointer data)
 {
-    gtk_signal_emit(GTK_OBJECT(data), gnome_pgp_sign_signals[GNOME_PGP_CANCEL_SIGNAL]);
+    gtk_signal_emit(
+        GTK_OBJECT(data),
+        gnome_pgp_sign_signals[GNOME_PGP_CANCEL_SIGNAL]);
     free(GNOME_PGP_SIGN(data)->obuf);
     GNOME_PGP_SIGN(data)->obuf=NULL;
     GNOME_PGP_SIGN(data)->obufsize=0;
     gtk_widget_destroy(GTK_WIDGET(data));
 }
 
-static gint MessageBox_ok_cb(GtkWidget *widget, gpointer data)
-{
-    gtk_widget_destroy(GTK_WIDGET(data));
-    return TRUE;
-}
-
-void MessageBox(const gchar *title, const gchar *message)
-{
-    GtkWidget *window;
-    GtkWidget *box;
-    GtkWidget *buttonbox;
-    GtkWidget *bok;
-    GtkWidget *msg;
-
-    window = gtk_window_new(GTK_WINDOW_DIALOG);
-    gtk_window_set_title(GTK_WINDOW(window), title);
-
-    box = gtk_vbox_new(FALSE,0);
-    gtk_container_add( GTK_CONTAINER(window), box);
-    gtk_widget_show(box);
-
-    msg = gtk_label_new(message);
-    gtk_label_set_justify(GTK_LABEL(msg), GTK_JUSTIFY_CENTER);
-    gtk_box_pack_start(GTK_BOX(box), msg, FALSE, FALSE, GNOME_PAD_SMALL);
-    gtk_widget_show(msg);
-
-    buttonbox = gtk_hbutton_box_new();
-    gtk_box_pack_start(GTK_BOX(box), buttonbox, FALSE, FALSE, GNOME_PAD_SMALL);
-    gtk_widget_show(buttonbox);
-
-    bok=gnome_stock_button(GNOME_STOCK_BUTTON_OK);
-    gtk_box_pack_start(GTK_BOX(buttonbox), bok, FALSE, FALSE, GNOME_PAD_SMALL);
-    gtk_signal_connect(
-        GTK_OBJECT (bok),
-        "clicked",
-        GTK_SIGNAL_FUNC(MessageBox_ok_cb),
-        (gpointer) window);
-    gtk_widget_show(bok); 
-/*    gtk_widget_set_usize(window, 500, 350);*/
-    gtk_widget_show(window);
-    gtk_widget_grab_focus(window);
-}
-
 static void enc_cb (GtkWidget *widget, GnomePgpSign *data)
 {
     GtkWidget* window;
@@ -469,82 +502,155 @@ static void enc_ok_cb (GtkWidget *widget, struct signpack *data)
     sign_cancel_cb(widget, data);
 }
 
+static int gpgp_MessageBox_cb(
+    GnomeDialog *dialog, gint button_number, gpointer data)
+{
+    gnome_dialog_close(dialog);
+    return FALSE;
+}
+
+void gpgp_MessageBox(const gchar *type, const gchar *text)
+{
+    GtkWidget * label;
+    GtkWidget * dialog;
+
+    if (type == NULL)
+        type = _("Error");
+
+    label  = gtk_label_new(text);
+    assert(label != NULL);
+
+    dialog = gnome_dialog_new(type, GNOME_STOCK_BUTTON_CLOSE, NULL);
+    gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox),
+                       label, TRUE, TRUE, GNOME_PAD);
+    gtk_signal_connect(GTK_OBJECT(dialog), "clicked",
+                       GTK_SIGNAL_FUNC(gpgp_MessageBox_cb),
+                       NULL);
+    gtk_widget_show(label);
+    gtk_widget_show(dialog);
+}
+
+/*
+ * go_cb()
+ *
+ * Procedure handles "OK" button in the sign/encrypt dialog.
+ *
+ * History:
+ * 19-May-99 tftp       Added checks, warnings about missing data.
+ */
 static void go_cb (GtkWidget *widget, GnomePgpSign *data)
 {
     struct finish_pack* pack=g_malloc(sizeof(struct finish_pack));
     char optline[1000]="";
+    int do_armor, do_sign, do_encrypt, do_textmode, do_clearsign;
  
+    assert(widget != NULL);
+    assert(data != NULL);
+
+    /* Collect selected options in GTK-specific manner */
+
+    do_sign = GTK_TOGGLE_BUTTON(data->sign)->active;
+    do_encrypt = GTK_TOGGLE_BUTTON(data->enc)->active;
+    do_textmode = GTK_TOGGLE_BUTTON(data->textmode)->active;
+    do_armor = GTK_TOGGLE_BUTTON(data->armor)->active;
+    do_clearsign = GTK_TOGGLE_BUTTON(data->clearsig)->active;
+
     pack->needpip=0;
     pack->data=data;
 
-    /* ??? insert code here ??? */
+    if (do_sign)
+    {
+        int len, passlen;
+        char *pass, *seckey;
 
-    if ( GTK_TOGGLE_BUTTON(data->sign)->active )
-    { /* sign */
-        char* tmp;
-        char* pass=gtk_entry_get_text(data->pass);
+        pass = gtk_entry_get_text(data->pass);
+        passlen = strlen(pass);
+        if (passlen <= 0)
+        {
+            gpgp_MessageBox(NULL,_("No passphrase specified!"));
+            return;
+        }
+
+        seckey=gtk_entry_get_text(GTK_ENTRY(gnome_entry_gtk_entry(data->sec)));
+        len = strlen(seckey);
+        if (len <= 0)
+        {
+            gpgp_MessageBox(NULL,_("No secret key specified!"));
+            return;
+        }
+
+        /* Create, load pipe with passphrase data */
         pipe(pack->pip);
         pack->needpip=1;
-        write(pack->pip[1], pass, strlen(pass));
+        write(pack->pip[1], pass, passlen);
         close(pack->pip[1]);
 
+        len = strlen(optline);
         g_snprintf(
-            optline, sizeof(optline),
-            "%s --sign -u \"=%s\" --passphrase-fd %d --set-filename %s",
-            tmp = g_strdup(optline),
-            gtk_entry_get_text(GTK_ENTRY(gnome_entry_gtk_entry(data->sec))),
-            pack->pip[0], data->filename);
-        g_free(tmp);
+            optline+len, sizeof(optline)-len,
+            " --sign -u \"=%s\" --passphrase-fd %d",
+            seckey, pack->pip[0]);
+
+        /*
+         * Optionally we specify file name. We do not really need it
+         * for data retrieval because data has been already placed
+         * into memory buffer. The file name may be used by OpenPGP
+         * to restore original file name upon decryption. If we got
+         * data off the clipboard (integrated editor) then we got no
+         * file name (NULL) and have to skip that option.
+         */
+        if (data->filename != NULL)
+        {
+            strcat(optline, " --set-filename ");
+            strcat(optline, data->filename);
+        }
     }
 
-    if ( GTK_TOGGLE_BUTTON(data->enc)->active )
-    { /* encrypt */
-        char* tmp;
-        g_snprintf(
-            optline, sizeof(optline),
-            "%s --encrypt -r \"=%s\"",
-            tmp=g_strdup(optline),
-            gtk_entry_get_text(GTK_ENTRY(gnome_entry_gtk_entry(data->pub))));
-        g_free(tmp);
+    if (do_encrypt)
+    {
+        int len;
+        char *pubkey;
+
+        pubkey=gtk_entry_get_text(GTK_ENTRY(gnome_entry_gtk_entry(data->pub)));
+        len = strlen(pubkey);
+        if (len <= 0)
+        {
+            gpgp_MessageBox(NULL,_("No public key specified!"));
+            return;
+        }
+        strcat(optline, " --encrypt -r \"=");
+        strcat(optline, pubkey);
+        strcat(optline, "\"");
     }
 
-    if ( !GTK_TOGGLE_BUTTON(data->enc)->active  &&
-         !GTK_TOGGLE_BUTTON(data->sign)->active)
-    { /* store */
-        char* tmp;
-        g_snprintf(optline,sizeof(optline), "%s --store",
-                   tmp=g_strdup(optline));
-        g_free(tmp);
-    }
+    if (!(do_sign || do_encrypt)) /* store - neither sign nor encrypt */
+        strcat(optline, " --store");
  
-    if ( GTK_TOGGLE_BUTTON(data->textmode)->active)
-    { /* text */
-        char* tmp;
-        g_snprintf(optline,sizeof(optline), "%s --textmode",
-                   tmp=g_strdup(optline));
-        g_free(tmp);
-    }
+    if (do_textmode)
+        strcat(optline, " --textmode");
 
-    if ( GTK_TOGGLE_BUTTON(data->armor)->active)
-    { /* armor */
-        char* tmp;
-        g_snprintf(optline,sizeof(optline), "%s --armor",
-                   tmp=g_strdup(optline));
-        g_free(tmp);
-    }
+    if (do_armor)
+        strcat(optline, " --armor");
  
-    if ( GTK_TOGGLE_BUTTON(data->clearsig)->active)
-    { /* clearsig */
-        char* tmp;
-        g_snprintf(optline,sizeof(optline), "%s --clearsign",
-                   tmp=g_strdup(optline));
-        g_free(tmp);
-    }
+    if (do_clearsign)
+        strcat(optline, " --clearsign");
  
     gtk_widget_hide(GTK_WIDGET(data));
+#if 0
+    {
+        char *tmp = (char *) malloc(data->bufsize+100);
+        assert(tmp != NULL);
+        sprintf(tmp,"%d:[%.*s]\n",data->bufsize,data->bufsize,data->buf);
+        gpgp_MessageBox(_("Debug"),tmp);
+        free(tmp);
+    }
+#endif
     pgp_sign_action(
-        optline, data->buf, data->bufsize,
-        &data->obuf, &data->obufsize,
+        optline,
+        data->buf,
+        data->bufsize,
+        &data->obuf,
+        &data->obufsize,
         (PgmanActionFunc) sign_finish_cb,
         pack);
 }
@@ -565,7 +671,9 @@ static void sign_finish_cb(struct finish_pack* pack2)
     if (pgman_error)
     {
         pack2->data->error_info=pgman_error;
-        gtk_signal_emit(GTK_OBJECT(pack2->data), gnome_pgp_sign_signals[GNOME_PGP_ERROR_SIGNAL]);
+        gtk_signal_emit(
+            GTK_OBJECT(pack2->data),
+            gnome_pgp_sign_signals[GNOME_PGP_ERROR_SIGNAL]);
         g_free(pack2);
         return;
     }
@@ -580,22 +688,35 @@ static void sign_finish_cb(struct finish_pack* pack2)
             NULL);
         pack->box  = okbox;
         pack->page = GTK_WIDGET(pack2->data);
-        gtk_widget_show(okbox);
- 
         gnome_dialog_button_connect(
-            GNOME_DIALOG(okbox), 0, GTK_SIGNAL_FUNC (okbox_ok_cb), pack);
+            GNOME_DIALOG(okbox),
+            0,
+            GTK_SIGNAL_FUNC(okbox_ok_cb),
+            pack);
         check = gtk_check_button_new_with_label(_("Show next time"));
         gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(check),TRUE);
-        gtk_signal_connect(GTK_OBJECT(check),"toggled", GTK_SIGNAL_FUNC(next_time_cb),NULL);   
-        gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(okbox)->vbox),check,
-                           FALSE, TRUE, GNOME_PAD_SMALL);
+        gtk_signal_connect(
+            GTK_OBJECT(check),
+            "toggled",
+            GTK_SIGNAL_FUNC(next_time_cb),
+            NULL);
+        gtk_box_pack_start(
+            GTK_BOX(GNOME_DIALOG(okbox)->vbox),
+            check,
+            FALSE,
+            TRUE,
+            GNOME_PAD_SMALL);
         gtk_widget_show(check);
+        gtk_widget_show(okbox);
     }
+    else
+        gtk_widget_destroy(GTK_WIDGET(pack2->data));
     g_free(pack2);
 }
 
 static void next_time_cb(GtkToggleButton* widget, void* data)
 {
+    assert(widget != NULL);
     gpgp_options.sign_verbose = widget->active;
     gnome_config_set_bool("gpgp/Options/Sign Verbose", gpgp_options.sign_verbose);
     gnome_config_sync();
@@ -603,9 +724,12 @@ static void next_time_cb(GtkToggleButton* widget, void* data)
 
 static void okbox_ok_cb (GtkWidget *widget, struct ok_pack* data)
 {
-    gtk_widget_destroy(data->page);
-    gtk_widget_destroy(data->box);
-    g_free(data);
+    if (data != NULL)
+    {
+        gtk_widget_destroy(data->page);
+        gtk_widget_destroy(data->box);
+        g_free(data);
+    }
 }
 
 static gint toggle_pgppass_cb (GtkWidget *widget, GnomePgpSign* data)
@@ -617,7 +741,7 @@ static gint toggle_pgppass_cb (GtkWidget *widget, GnomePgpSign* data)
         return TRUE;
     if(GTK_TOGGLE_BUTTON(data->enable)->active)
     {
-        const char *cp = getenv("PGPPASS");
+        const char *cp = getenv(ENV_PGPPASS);
         int pgppass_valid = FALSE;
         if (cp != NULL)
         {
@@ -630,10 +754,19 @@ static gint toggle_pgppass_cb (GtkWidget *widget, GnomePgpSign* data)
         }
         if (!pgppass_valid)
         {
-            MessageBox(_("Error"), _("Environment variable PGPPASS is not defined or empty"));
+            GtkWidget *window;
+
+            window = gnome_message_box_new(
+                _("Environment variable PGPPASS is not defined or empty"),
+                GNOME_MESSAGE_BOX_WARNING,
+                GNOME_STOCK_BUTTON_OK, NULL );
+            gtk_widget_show(window);
+
             /* Do not try to access PGPPASS later in this session */
             pgppass_ignore = TRUE;
-            gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(data->enable), FALSE);
+            gtk_toggle_button_set_state(
+                GTK_TOGGLE_BUTTON(data->enable),
+                FALSE);
             gtk_widget_set_sensitive(GTK_WIDGET(data->enable), FALSE);
             return TRUE;
         }
@@ -655,7 +788,9 @@ static void toggle_sign_cb (GtkWidget *widget, GnomePgpSign* data)
     is_sign = GTK_TOGGLE_BUTTON(data->sign)->active;
     gtk_widget_set_sensitive(GTK_WIDGET(data->sec), is_sign);
     gtk_widget_set_sensitive(GTK_WIDGET(data->pass), is_sign);
-    gtk_widget_set_sensitive(GTK_WIDGET(data->enable), is_sign && !pgppass_ignore);
+    gtk_widget_set_sensitive(
+        GTK_WIDGET(data->enable),
+        is_sign && !pgppass_ignore && (getenv(ENV_PGPPASS) != NULL));
     gtk_widget_set_sensitive(GTK_WIDGET(data->bsign), is_sign);
     if (is_sign)
         toggle_pgppass_cb(widget, data);
