@@ -1,4 +1,4 @@
-/* $Revision: 1.2 $ */
+/* $Revision: 1.3 $ */
 /*
  *  gpgp: Gnome/GTK Front for PGP
  *  Copyright (C) 1998  Max Valianskiy
@@ -21,6 +21,7 @@
 #include "../config.h"
 #include "../version.h"
 
+#include <assert.h>
 #include <gnome.h>
 
 #include "gpgp.h"
@@ -61,7 +62,9 @@ guint gnome_pgp_unsign_get_type()
             (GtkArgSetFunc) NULL,
             (GtkArgGetFunc) NULL
         };
-        gnome_pgp_unsign_type = gtk_type_unique (gtk_widget_get_type (), &gnome_pgp_unsign_info);
+        gnome_pgp_unsign_type = gtk_type_unique(
+            gtk_widget_get_type(),
+            &gnome_pgp_unsign_info);
     }
     return gnome_pgp_unsign_type;
 }
@@ -85,7 +88,10 @@ static void gnome_pgp_unsign_class_init(GnomePgpUnSignClass *class)
             object_class->type,
             GTK_SIGNAL_OFFSET (GnomePgpUnSignClass,cancel),
             gtk_signal_default_marshaller, GTK_TYPE_NONE, 0);
-    gtk_object_class_add_signals (object_class, gnome_pgp_unsign_signals, LAST_SIGNAL);
+    gtk_object_class_add_signals(
+        object_class,
+        gnome_pgp_unsign_signals,
+        LAST_SIGNAL);
     class->error = NULL;
 }
 
@@ -93,13 +99,13 @@ static void gnome_pgp_unsign_init (GnomePgpUnSign *page)
 {
 }
 
-void gnome_pgp_unsign_action(GnomePgpUnSign* page)
+void gnome_pgp_unsign_action(GnomePgpUnSign *page)
 {
     page->obuf = g_malloc(page->bufsize);
     memcpy(page->obuf, page->buf, page->bufsize);
     page->obufsize = page->bufsize;
-    page->filename="filename";
     gtk_widget_hide(GTK_WIDGET(page));
+
     pgp_unsign_action(
         page->buf, page->bufsize,
         &page->obuf, &page->obufsize,
@@ -117,20 +123,23 @@ static void okbox_ok_cb (GtkWidget *widget, struct ok_pack* data)
 static void next_time_cb(GtkToggleButton* widget, void* data)
 {
     gpgp_options.sign_verbose = widget->active;
-    gnome_config_set_bool("gpgp/Options/UnSign Verbose", gpgp_options.sign_verbose);
+    gnome_config_set_bool(
+        "gpgp/Options/UnSign Verbose",
+        gpgp_options.sign_verbose);
     gnome_config_sync();
 }
 
 static void unsign_finish_cb(GnomePgpUnSign* page)
 {
-printf("unsign_finish_cb\n");
     if (pgman_error)
     {
-        page->error_info=pgman_error;
-        gtk_signal_emit(GTK_OBJECT(page), gnome_pgp_unsign_signals[GNOME_PGP_ERROR_SIGNAL]); 
+        LogTextMessage(pgman_error);
+        page->error_info = pgman_error;
+        gtk_signal_emit(
+            GTK_OBJECT(page),
+            gnome_pgp_unsign_signals[GNOME_PGP_ERROR_SIGNAL]); 
         return;
     }
-
     if (gpgp_options.unsign_verbose)
     {
         struct ok_pack* pack;
@@ -138,29 +147,48 @@ printf("unsign_finish_cb\n");
         GtkWidget* check;
  
         pack = g_malloc(sizeof(struct ok_pack));
- 
-        okbox = gnome_message_box_new(_("Operation complete"), GNOME_MESSAGE_BOX_INFO, GNOME_STOCK_BUTTON_OK, NULL);
+        assert(pack != NULL);
+        okbox = gnome_message_box_new(
+            _("Operation complete"),
+            GNOME_MESSAGE_BOX_INFO,
+            GNOME_STOCK_BUTTON_OK,
+            NULL);
         pack->box  = okbox;
         pack->page = GTK_WIDGET(page);
-        gtk_widget_show(okbox);
  
-        gnome_dialog_button_connect (GNOME_DIALOG (okbox), 0, GTK_SIGNAL_FUNC (okbox_ok_cb), pack);
+        gnome_dialog_button_connect(
+            GNOME_DIALOG (okbox),
+            0,
+            GTK_SIGNAL_FUNC (okbox_ok_cb),
+            pack);
  
         check = gtk_check_button_new_with_label(_("Show next time"));
         gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(check),TRUE);
-        gtk_signal_connect(GTK_OBJECT(check),"toggled", GTK_SIGNAL_FUNC(next_time_cb),NULL);   
-        gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(okbox)->vbox),check,
-                           FALSE, TRUE, GNOME_PAD_SMALL);
+        gtk_signal_connect(
+            GTK_OBJECT(check),
+            "toggled",
+            GTK_SIGNAL_FUNC(next_time_cb),
+            NULL);   
+        gtk_box_pack_start(
+            GTK_BOX(GNOME_DIALOG(okbox)->vbox),
+            check,
+            FALSE,
+            TRUE,
+            GNOME_PAD_SMALL);
         gtk_widget_show(check);
+        gtk_widget_show(okbox);
     }
+    else
+        gtk_widget_destroy(GTK_WIDGET(page));
 }
 
-GtkWidget *gnome_pgp_unsign_new (char* buf, int bufsize)
+GtkWidget *gnome_pgp_unsign_new (char* buf, int bufsize, const char *filename)
 {
     GnomePgpUnSign* page;
 
     page = gtk_type_new (gnome_pgp_unsign_get_type ());
     page->buf = buf;
     page->bufsize = bufsize;
-    return GTK_WIDGET (page);
+    page->filename = (filename != NULL) ? strdup(filename) : NULL;
+    return GTK_WIDGET(page);
 }
