@@ -17,7 +17,7 @@
     License along with this library; if not, write to the Free
     Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Revision: 1.2 $ 
+    $Revision: 1.3 $ 
 
 */
 
@@ -26,7 +26,7 @@
 
 #include <glib.h>
 
-extern char* pgman_error;
+extern const char *pgman_error;
 
 GList* get_keylist(char* ring, int is_secret);
 void pgp_add_key(char* file, char* ring);
@@ -44,6 +44,9 @@ struct key_options
  GList* signatures;
 };
 
+/* gpgp_show.c */
+void pgman_ShowErrorFromFiledesc(int fd);
+
 void get_key_options(char* ring, char* uid, struct key_options* options);
 
 typedef void (* PgmanActionFunc) (gpointer data);
